==> kipi-plugins-trinity-3.5.13.2.tar.xz: kipi-plugins-trinity-3.5.13.2/kipi-plugins/ipodexport/ipodlistitem.h <==
/***************************************************************************
 * copyright            : (C) 2006 Seb Ruiz <me@sebruiz.net>               *
 **************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef IPODLISTITEM_H
#define IPODLISTITEM_H

extern "C" {
#include <gpod/itdb.h>
}

#include <klistview.h>

namespace IpodExport
{

    class IpodAlbumItem : public KListViewItem
    {
        public:
            IpodAlbumItem( TQListView *parent, TQListViewItem *after, Itdb_PhotoAlbum *pa );

            TQString          name()       const { return m_name;       }
            Itdb_PhotoAlbum *photoAlbum() const { return m_photoAlbum; }

            void setPhotoAlbum( Itdb_PhotoAlbum *pa );
            void setName( const TQString & name );

        private:
            TQString          m_name;
            Itdb_PhotoAlbum *m_photoAlbum;
    };

    class IpodPhotoItem : public KListViewItem
    {
        public:
            IpodPhotoItem( IpodAlbumItem *parent, IpodPhotoItem *after, Itdb_Artwork *art );

            Itdb_Artwork *artwork() const { return m_artwork; }
            void          setArtwork( Itdb_Artwork *art );

        private:
            Itdb_Artwork *m_artwork;
    };

}

#endif  // IPODLISTITEM_H

==> kipi-plugins-trinity-14.0.8.tar.xz: kipi-plugins-trinity-14.0.8/kipi-plugins/ipodexport/ipodlistitem.h <==
/***************************************************************************
 * copyright            : (C) 2006 Seb Ruiz <me@sebruiz.net>               *
 **************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef IPODLISTITEM_H
#define IPODLISTITEM_H

extern "C" {
#include <gpod/itdb.h>
}

#include <tdelistview.h>

namespace IpodExport
{

    class IpodAlbumItem : public TDEListViewItem
    {
        public:
            IpodAlbumItem( TQListView *parent, TQListViewItem *after, Itdb_PhotoAlbum *pa );

            TQString          name()       const { return m_name;       }
            Itdb_PhotoAlbum *photoAlbum() const { return m_photoAlbum; }

            void setPhotoAlbum( Itdb_PhotoAlbum *pa );
            void setName( const TQString & name );

        private:
            TQString          m_name;
            Itdb_PhotoAlbum *m_photoAlbum;
    };

    class IpodPhotoItem : public TDEListViewItem
    {
        public:
            IpodPhotoItem( IpodAlbumItem *parent, IpodPhotoItem *after, Itdb_Artwork *art );

            Itdb_Artwork *artwork() const { return m_artwork; }
            void          setArtwork( Itdb_Artwork *art );

        private:
            Itdb_Artwork *m_artwork;
    };

}

#endif  // IPODLISTITEM_H
